@@ -103,22 +103,25 @@ class Scene:
         :return: the Schematic object
         """
 
+        def update_box(box_pos_min, box_pos_max, pos):
+            # Update box_pos_min and box_pos_max checking pos
+            box_pos_min.x = pos.x if pos.x < box_pos_min.x else box_pos_min.x
+            box_pos_min.y = pos.y if pos.y < box_pos_min.y else box_pos_min.y
+            box_pos_min.z = pos.z if pos.z < box_pos_min.z else box_pos_min.z
+            box_pos_max.x = pos.x if pos.x > box_pos_max.x else box_pos_max.x
+            box_pos_max.y = pos.y if pos.y > box_pos_max.y else box_pos_max.y
+            box_pos_max.z = pos.z if pos.z > box_pos_max.z else box_pos_max.z
+
+            return box_pos_min, box_pos_max
+
         # Default init values
-        init_pos = Vec3(cls._position.x, cls._position.y, cls._position.z)
-        end_pos = Vec3(cls._position.x, cls._position.y, cls._position.z)
+        min_pos = Vec3(cls._position.x, cls._position.y, cls._position.z)
+        max_pos = Vec3(cls._position.x, cls._position.y, cls._position.z)
 
+        # Find the bounding box for the scene
         for thing in cls.things:
-            ip = thing.position
-            ep = thing.end_position
+            min_pos, max_pos = update_box(min_pos, max_pos, thing.position)
+            if thing.end_position:
+                min_pos, max_pos = update_box(min_pos, max_pos, thing.end_position)
 
-            # Update init position
-            init_pos.x = ip.x if ip.x < init_pos.x else init_pos.x
-            init_pos.y = ip.y if ip.y < init_pos.y else init_pos.y
-            init_pos.z = ip.z if ip.z < init_pos.z else init_pos.z
-
-            # Update end position
-            end_pos.x = ep.x if ep.x > end_pos.x else end_pos.x
-            end_pos.y = ep.y if ep.y > end_pos.y else end_pos.y
-            end_pos.z = ep.z if ep.z > end_pos.z else end_pos.z
-
-            build_schematic_nbt(init_pos, end_pos).write_file(file_path)
+        build_schematic_nbt(min_pos, max_pos).write_file(file_path)
